@@ -6,11 +6,12 @@
  * it under the terms of the GNU General Public License version 2, as
  * published by the Free Software Foundation.
  *
- * $Id: telak.c 1234 2006-06-06 16:17:33Z jd $
+ * $Id$
  */
 
 #define _GNU_SOURCE
 
+#include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -52,6 +53,11 @@ main(int argc, char **argv)
   /* Make conf */
   make_conf(argc, argv);
 
+  /* Register signal handler */
+  struct sigaction sigact = { .sa_handler = refresh, .sa_flags = 0 };
+  sigemptyset (&sigact.sa_mask);
+  sigaction(SIGUSR1, &sigact, NULL);
+
   init_x();
 
   check_cache_dir();
